@@ -3,7 +3,17 @@ import os
 import shutil
 import tempfile
 
-from nbdime.utils import strings_to_lists, revert_strings_to_lists, is_in_repo
+try:
+    from shutil import which
+except ImportError:
+    from backports.shutil_which import which
+
+import pytest
+
+from nbdime.utils import (
+    strings_to_lists, revert_strings_to_lists, is_in_repo,
+    locate_gitattributes
+)
 
 def test_string_to_lists():
     obj = {"c": [{"s": "ting\ntang", "o": [{"ot": "stream"}]}]}
@@ -35,3 +45,21 @@ def test_is_repo():
 
     finally:
         shutil.rmtree(tmpdir)
+
+
+def test_locate_gitattributes_local(git_repo):
+    gitattr = locate_gitattributes(scope=None)
+    assert gitattr is not None
+
+
+@pytest.mark.skipif(not which('git'), reason="Missing git.")
+def test_locate_gitattributes_global():
+    gitattr = locate_gitattributes(scope='global')
+    assert gitattr is not None
+
+
+@pytest.mark.skipif(not which('git'), reason="Missing git.")
+def test_locate_gitattributes_system():
+    gitattr = locate_gitattributes(scope='system')
+    assert gitattr is not None
+
